camelot.camelot.view.controls.editors.One2ManyEditor

Package camelot :: Package camelot :: Package view :: Package controls :: Module editors :: Class One2ManyEditor |
[hide private]
[frames] | no frames]

# Class One2ManyEditor

source code

Instance Methods | [hide private]
__init__(self, admin=None, parent=None, create_inline=False, **kw) | source code
setModel(self, model) | source code
newRow(self) | source code
deleteSelectedRows(self) Delete the selected rows in this tableview | source code
createFormForIndex(self, index) | source code

Method Details | [hide private]

### __init__(self, admin=None, parent=None, create_inline=False, **kw) (Constructor) | source code
Parameters: `admin` - the Admin interface for the objects on the one side of the relation `create_inline` - if False, then a new entity will be created within a new window, if True, it will be created inline after creating the editor, setEntityInstance needs to be called to set the actual data to the editor